Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/prusa3d/PrusaSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbubnikv <bubnikv@gmail.com>2017-01-20 17:21:05 +0300
committerbubnikv <bubnikv@gmail.com>2017-01-20 17:21:05 +0300
commitff25c0ccc2da96ab9991a00a74eca3022c7028fd (patch)
tree5f942d34ab96404533c9edfbeee91eeb0b371712 /xs/src/libslic3r/SupportMaterial.hpp
parent08351b5e485d614615c862f3f9957c7e771cefcb (diff)
Improvements of the new support generator:
Variable path thickness for all support layers to avoid over-extrusion. Supports only in grid cells below the top contacts. Provision for filtering excessively long perimeter pieces of the support infill lines.
Diffstat (limited to 'xs/src/libslic3r/SupportMaterial.hpp')
-rw-r--r--xs/src/libslic3r/SupportMaterial.hpp16
1 files changed, 10 insertions, 6 deletions
diff --git a/xs/src/libslic3r/SupportMaterial.hpp b/xs/src/libslic3r/SupportMaterial.hpp
index 48c5fc3bd..a436b1da5 100644
--- a/xs/src/libslic3r/SupportMaterial.hpp
+++ b/xs/src/libslic3r/SupportMaterial.hpp
@@ -59,13 +59,16 @@ public:
idx_object_layer_above(size_t(-1)),
idx_object_layer_below(size_t(-1)),
bridging(false),
- aux_polygons(NULL)
+ contact_polygons(nullptr),
+ overhang_polygons(nullptr)
{}
~MyLayer()
{
- delete aux_polygons;
- aux_polygons = NULL;
+ delete contact_polygons;
+ contact_polygons = nullptr;
+ delete overhang_polygons;
+ overhang_polygons = nullptr;
}
bool operator==(const MyLayer &layer2) const {
@@ -106,9 +109,10 @@ public:
// Polygons to be filled by the support pattern.
Polygons polygons;
- // Currently for the contact layers only: Overhangs are stored here.
- // MyLayer owns the aux_polygons, they are freed by the destructor.
- Polygons *aux_polygons;
+ // Currently for the contact layers only.
+ // MyLayer owns the contact_polygons and overhang_polygons, they are freed by the destructor.
+ Polygons *contact_polygons;
+ Polygons *overhang_polygons;
};
// Layers are allocated and owned by a deque. Once a layer is allocated, it is maintained